@@ -19,8 +19,12 @@
  +-----------------------------------------------------------------------+
 */
 
+if (PHP_VERSION_ID < 70300) {
+    die("Unsupported PHP version. Required PHP >= 7.3.");
+}
+
 // application constants
-define('RCMAIL_VERSION', '1.5.2');
+define('RCMAIL_VERSION', '1.6.6');
 define('RCMAIL_START', microtime(true));
 
 if (!defined('INSTALL_PATH')) {
@@ -39,7 +43,7 @@ define('RCUBE_INSTALL_PATH', INSTALL_PATH);
 define('RCUBE_CONFIG_DIR',  RCMAIL_CONFIG_DIR.'/');
 
 // Show basic error message on fatal PHP error
-register_shutdown_function('rcmail_fatal_error');
+register_shutdown_function('rcmail_error_handler');
 
 // RC include folders MUST be included FIRST to avoid other
 // possible not compatible libraries (i.e PEAR) to be included
@@ -99,27 +103,37 @@ function rcmail_autoload($classname)
 }
 
 /**
- * Show basic error message on fatal PHP error
+ * Show a generic error message on fatal PHP error
  */
-function rcmail_fatal_error()
+function rcmail_error_handler()
 {
     $error = error_get_last();
 
     if ($error && ($error['type'] === E_ERROR || $error['type'] === E_PARSE)) {
-        if (php_sapi_name() === 'cli') {
-            echo "Fatal error: Please check the Roundcube error log and/or server error logs for more information.\n";
-        }
-        elseif (!empty($_REQUEST['_remote'])) {
-            // Ajax request from UI
-            header('Content-Type: application/json; charset=UTF-8');
-            echo json_encode(['code' => 500, 'message' => "Internal Server Error"]);
-        }
-        else {
-            if (!defined('RCUBE_FATAL_ERROR_MSG')) {
-                define('RCUBE_FATAL_ERROR_MSG', INSTALL_PATH . 'program/resources/error.html');
-            }
-
-            echo file_get_contents(RCUBE_FATAL_ERROR_MSG);
-        }
+        rcmail_fatal_error();
     }
 }
+
+/**
+ * Raise a generic error message on error
+ */
+function rcmail_fatal_error()
+{
+    if (php_sapi_name() === 'cli') {
+        echo "Fatal error: Please check the Roundcube error log and/or server error logs for more information.\n";
+    }
+    elseif (!empty($_REQUEST['_remote'])) {
+        // Ajax request from UI
+        header('Content-Type: application/json; charset=UTF-8');
+        echo json_encode(['code' => 500, 'message' => "Internal Server Error"]);
+    }
+    else {
+        if (!defined('RCUBE_FATAL_ERROR_MSG')) {
+            define('RCUBE_FATAL_ERROR_MSG', INSTALL_PATH . 'program/resources/error.html');
+        }
+
+        echo file_get_contents(RCUBE_FATAL_ERROR_MSG);
+    }
+
+    exit;
+}
